@@ -325,9 +325,12 @@ class sketch_from_svg:
     
 
     def load_svg(self):
+        print('loading data')
         paths,attributes,svg_att = svg2paths2(self.path)
-        self.height = int(svg_att["height"])
-        self.width = int(svg_att["width"])
+        h = svg_att["height"]
+        w = svg_att['width']
+        self.height = int(h[:h.find('.')])
+        self.width = int(w[:w.find('.')])
 
         res = []
         for i in tqdm(attributes):
